==> haskell-fsnotify-0.3.0.1-275-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fsnotify.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 fsnotify
version:              0.3.0.1
visibility:           public
id:                   fsnotify-0.3.0.1-6Bn5fHdglE25hrQz49e54z
key:                  fsnotify-0.3.0.1-6Bn5fHdglE25hrQz49e54z
license:              BSD-3-Clause
maintainer:           Tom McLaughlin <tom@codedown.io>
author:               Mark Dittmer <mark.s.dittmer@gmail.com>, Niklas Broberg
homepage:             https://github.com/haskell-fswatch/hfsnotify
synopsis:             Cross platform library for file change notification.
description:
    Cross platform library for file creation, modification,
    and deletion notification. This library builds upon
    existing libraries for platform-specific Windows, Mac,
    and Linux filesystem event notification.

category:             Filesystem
abi:                  57779cfe18fa405723d049ef5a4b9155
exposed:              True
exposed-modules:      System.FSNotify System.FSNotify.Devel
hidden-modules:
    System.FSNotify.Listener System.FSNotify.Path
    System.FSNotify.Polling System.FSNotify.Types System.FSNotify.Linux

import-dirs:          /usr/lib/ghc-9.0.2/site-local/fsnotify-0.3.0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/fsnotify-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fsnotify
hs-libraries:         HSfsnotify-0.3.0.1-6Bn5fHdglE25hrQz49e54z
depends:
    async-2.2.4-DsK1F0iuVhj9HaenwCyvAG base-4.15.1.0
    bytestring-0.10.12.1 containers-0.6.4.1 directory-1.3.6.2
    filepath-1.4.2.1 hinotify-0.4.1-2V7JFmNonk97ITOSJz4Fud
    shelly-1.10.0-EyHBCcs5LACCWCuvkDEqNk text-1.2.5.0 time-1.9.3
    unix-2.7.2.2 unix-compat-0.5.4-FTzJDG4psNuKZpJlJ2Zo5B

haddock-interfaces:   /usr/share/doc/haskell-fsnotify/html/fsnotify.haddock
haddock-html:         /usr/share/doc/haskell-fsnotify/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fsnotify-0.3.0.1-284-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fsnotify.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 fsnotify
version:              0.3.0.1
visibility:           public
id:                   fsnotify-0.3.0.1-3FNvDfhXRKL7GXvO6IDfhE
key:                  fsnotify-0.3.0.1-3FNvDfhXRKL7GXvO6IDfhE
license:              BSD-3-Clause
maintainer:           Tom McLaughlin <tom@codedown.io>
author:               Mark Dittmer <mark.s.dittmer@gmail.com>, Niklas Broberg
homepage:             https://github.com/haskell-fswatch/hfsnotify
synopsis:             Cross platform library for file change notification.
description:
    Cross platform library for file creation, modification,
    and deletion notification. This library builds upon
    existing libraries for platform-specific Windows, Mac,
    and Linux filesystem event notification.

category:             Filesystem
abi:                  28106699b710b6eb5589f6aeec73f6c2
exposed:              True
exposed-modules:      System.FSNotify System.FSNotify.Devel
hidden-modules:
    System.FSNotify.Listener System.FSNotify.Path
    System.FSNotify.Polling System.FSNotify.Types System.FSNotify.Linux

import-dirs:          /usr/lib/ghc-9.0.2/site-local/fsnotify-0.3.0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/fsnotify-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fsnotify
hs-libraries:         HSfsnotify-0.3.0.1-3FNvDfhXRKL7GXvO6IDfhE
depends:
    async-2.2.4-256lhPDrTpH6romyyjDcSx base-4.15.1.0
    bytestring-0.10.12.1 containers-0.6.4.1 directory-1.3.6.2
    filepath-1.4.2.1 hinotify-0.4.1-AXws5lQmPpvJNU4L1ysONp
    shelly-1.10.0-EpMD7cX5LEKJ3jC5HOwqPK text-1.2.5.0 time-1.9.3
    unix-2.7.2.2 unix-compat-0.5.4-FTzJDG4psNuKZpJlJ2Zo5B

haddock-interfaces:   /usr/share/doc/haskell-fsnotify/html/fsnotify.haddock
haddock-html:         /usr/share/doc/haskell-fsnotify/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
